-- | Aztecs is a type-safe and friendly ECS for games and more.
--
-- An ECS is a modern approach to organizing your application state as a database,
-- providing patterns for data-oriented design and parallel processing.
module Aztecs (module Aztecs.ECS, module Aztecs.Hierarchy) where

import Aztecs.ECS
import Aztecs.Hierarchy
